# The fwdpy11 home page

This is the homepage for __fwdpy11__, which is an Python package for forward-time population- and quantitative- genetic simulations.

# What is fwdpy11?

fwdpy11 combines the power of [fwdpp](http://molpopgen.github.io) and Python to create a powerful environment for
forward-time simulation.

fwdpy11 is based on [pybind11](https://github.com/pybind/pybind11), and replaces
[fwdpy](http://molopgen.github.io/fwdpy), which was based on [Cython](http://www.cython.org).

## Source code

The source code is [here](https://github.com/molpopgen/fwdpy11).

## Documentation

The manual is automatically generated from the master and dev branches of the fwdpy11 [git
repo](https://github.com/molpopgen/fwdpy11):

* [latest/master](http://fwdpy11.readthedocs.io)
* [development branch](http://fwdpy11.readthedocs.io/en/dev/)

The manual contains examples of fwdpy11's features.

## Citation

If you use __fwdpy11__ for yor research, please cite the following manuscript, which is the basis for this package:

* Thornton, K. R. (2014) A C++ template library for efficient forward-time population genetic simulation of large populations.  Genetics 98:157-166  PMID: 24950894, [Manuscript](http://www.genetics.org/content/198/1/157.abstract), [Software](https://github.com/molpopgen/fwdpp)

